@@ -90,7 +90,7 @@ async def on_message(message):
 
     dir_path = None
 
-    link_given = False
+    song_name_given = False
 
     on_message.triggering_message = message
 
@@ -248,28 +248,27 @@ async def on_message(message):
                 
                 try:
                     if len(message.content.split(" ")) >= 2:
-                        if "https://" in message.content.split(" ")[1]:
-                            dir_path = os.path.dirname(os.path.realpath(__file__))
-                            link_given = True
-                            song_name = random.randint(1, 1000)
-                            if platform.system() == "Windows":
-                                command_dict[c]["source_to_play"] = f"{dir_path}\{song_name}.mp3"
-                                if "Usage" not in subprocess.getoutput("youtube-dl"):
-                                    if "Usage" not in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
-                                        print("Please install YouTube-dl to play music.")
-                                        return
-                                subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
-                            if platform.system() != "Windows":
-                                command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
-                                if "Usage" in subprocess.getoutput("youtube-dl"):
-                                    print("Please install Youtube-dl to continue")
+                        dir_path = os.path.dirname(os.path.realpath(__file__))
+                        song_name_given = True
+                        song_name = random.randint(1, 1000)
+                        if platform.system() == "Windows":
+                            command_dict[c]["source_to_play"] = f"{dir_path}\{song_name}.mp3"
+                            if "Usage" not in subprocess.getoutput("youtube-dl"):
+                                if "Usage" not in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
+                                    print("Please install YouTube-dl to play music.")
                                     return
-                                subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 {message.content.split(' ')[1]}", shell=True)
+                            subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 'ytsearch:{message.content.strip(' ')[1]}'", shell=True)
+                        if platform.system() != "Windows":
+                            command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
+                            if "Usage" in subprocess.getoutput("youtube-dl"):
+                                print("Please install Youtube-dl to continue")
+                                return
+                            subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 'ytsearch:{message.content.split(' ')[1]}'", shell=True)
 
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
                     if command_dict[c]["source_to_play"] == None:
-                        if link_given != True:
+                        if song_name_given != True:
                             await message.channel.send("Please give a YouTube link to play, then try again.")
                             return
 
